@@ -114,6 +114,9 @@ signals:
     // Send a call control event.
     void controlEvent( const QSimControlEvent& event );
 
+    // Send calls list on status change
+    void callStatesChanged( QList<CallInfo> *list );
+
 private slots:
     // Transition the active dialing or alerting call to connected.
     void dialingToConnected();
@@ -121,6 +124,9 @@ private slots:
     // Transition the active dialing call to alerting.
     void dialingToAlerting();
 
+    // Transition the waiting call to incoming.
+    void waitingToIncoming();
+
     // Handle dial-backs.
     void dialBack();
     void dialBackWithHangup5();
